_me = frm_main_calendar_month.prototype;
function frm_main_calendar_month() {};

_me.__constructor = async function (sDataset, _date) {
	this.__date = new IcewarpDate(_date);

	var me = this;

	this.inp_month._ondateselect = function () {
		if (this._value() != me.__date.format(IcewarpDate.JULIAN)) {
			var d = this._getObjectDate();
			me.__date.month(d.month());
			me.__date.year(d.year());
			me._updateLabel();
		}
	};

	this.previous._onclick = function () {
		me.__date.subtract(1, 'month');
		me._updateLabel();
	};

	this.next._onclick = function () {
		me.__date.add(1, 'month');
		me._updateLabel();
	};

	this.today._onclick = function () {
		me.__date = new IcewarpDate();
		me._updateLabel();
	};

	await this._updateLabel(true);

	this.refresh._onclick = function() {
		gui.frm_main._getNew(function() {
			if (this._destructed) {
				return;
			}
			this.refresh._disabled(false);
			this.refresh._main.classList.remove('loading');
		}.bind(this));
		this.refresh._disabled(true);
		this.refresh._main.classList.add('loading');
	}.bind(this);
};

_me._updateLabel = async function (bSkip) {
	this.inp_month._value(this.__date, true);
	await this.calendar._range(this.__date.format(IcewarpDate.JULIAN));

	if (!bSkip)
		this._serverSort();
};
